==> topia-persistence-2.6.5-test-sources.jar: org/nuiton/topia/test/entities/PetDTO.java <==
package org.nuiton.topia.test.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import org.apache.commons.lang3.builder.ToStringBuilder;

public class PetDTO implements Serializable {

    public String name;

    public String type;

    public PersonDTO person;

    public RaceDTO race;

    protected final PropertyChangeSupport p = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        p.addPropertyChangeListener(listener);
    }

    public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener) {
        p.addPropertyChangeListener(propertyName, listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        p.removePropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(String propertyName, PropertyChangeListener listener) {
        p.removePropertyChangeListener(propertyName, listener);
    }

    public void setName(String value) {
        java.lang.String oldValue = this.name;
        this.name = value;
        p.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return name;
    }

    public void setType(String value) {
        java.lang.String oldValue = this.type;
        this.type = value;
        p.firePropertyChange("type", oldValue, value);
    }

    public String getType() {
        return type;
    }

    public void setPerson(PersonDTO value) {
        org.nuiton.topia.test.entities.PersonDTO oldValue = this.person;
        this.person = value;
        p.firePropertyChange("person", oldValue, value);
    }

    public PersonDTO getPerson() {
        return person;
    }

    public void setRace(RaceDTO value) {
        org.nuiton.topia.test.entities.RaceDTO oldValue = this.race;
        this.race = value;
        p.firePropertyChange("race", oldValue, value);
    }

    public RaceDTO getRace() {
        return race;
    }

    public String toString() {
        String result = new ToStringBuilder(this).
            append("name", this.name).
            append("type", this.type).
            append("race", this.race).
         toString();
        return result;
}

} //PetDTO

==> topia-persistence-2.6.9-test-sources.jar: org/nuiton/topia/test/entities/PetDTO.java <==
package org.nuiton.topia.test.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import org.apache.commons.lang3.builder.ToStringBuilder;

public class PetDTO implements Serializable {

    protected String topiaId;

    public String name;

    public String type;

    public PersonDTO person;

    public RaceDTO race;

    protected final PropertyChangeSupport p = new PropertyChangeSupport(this);

    public void setTopiaId(String topiaId) {
        this.topiaId = topiaId;
    }

    public String getTopiaId() {
        return topiaId;
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        p.addPropertyChangeListener(listener);
    }

    public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener) {
        p.addPropertyChangeListener(propertyName, listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        p.removePropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(String propertyName, PropertyChangeListener listener) {
        p.removePropertyChangeListener(propertyName, listener);
    }

    public void setName(String value) {
        java.lang.String oldValue = this.name;
        this.name = value;
        p.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return name;
    }

    public void setType(String value) {
        java.lang.String oldValue = this.type;
        this.type = value;
        p.firePropertyChange("type", oldValue, value);
    }

    public String getType() {
        return type;
    }

    public void setPerson(PersonDTO value) {
        org.nuiton.topia.test.entities.PersonDTO oldValue = this.person;
        this.person = value;
        p.firePropertyChange("person", oldValue, value);
    }

    public PersonDTO getPerson() {
        return person;
    }

    public void setRace(RaceDTO value) {
        org.nuiton.topia.test.entities.RaceDTO oldValue = this.race;
        this.race = value;
        p.firePropertyChange("race", oldValue, value);
    }

    public RaceDTO getRace() {
        return race;
    }

    public String toString() {
        String result = new ToStringBuilder(this).
            append("name", this.name).
            append("type", this.type).
            append("race", this.race).
         toString();
        return result;
}

} //PetDTO
